# Copyright 2025 The EasyDeL/eFormer Author @erfanzar (Erfan Zare Chavoshi).
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from .precision_types import DTYPE_MAPPING, DTYPE_TO_STRING_MAP, STRING_TO_DTYPE_MAP, put_dtype

__all__ = ("DTYPE_MAPPING", "DTYPE_TO_STRING_MAP", "STRING_TO_DTYPE_MAP", "put_dtype")
